<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Poll directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2015.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author:
	PaperThin Inc.
	M. Carroll
Name:
	poll_question_gallery_single_form_rh.cfm
Element:
	Poll Question Gallery
ADF App:
	pt_poll
Version:
	1.0.0
History:
	2010-02-10 - MFC - Created
	2016-02-26 - DRM - Resource detection exit
--->

<!--- if this module loads resources, do it here.. --->
<cfscript>
	application.ptPoll.scripts.loadJQuery();
	application.ptPoll.scripts.loadJQueryField();
	application.ptPoll.scripts.loadJQueryBlockUI();
</cfscript>

<!--- ... then exit if all we're doing is detecting required resources --->
<cfif Request.RenderState.RenderMode EQ "getResources">
  <cfexit>
</cfif>


<cfscript>
	// Force RH not to be cached
	request.element.isStatic = 0;
	
	// Get the items
	items = attributes.elementInfo.elementData.propertyValues;
	
	qIDList = "";
	
	// Number of the question to render
	qItem  = 1;
</cfscript>

<!--- Check that we have values --->	
<cfif ArrayLen(items)>
	<cfset qData = application.ptPoll.pollQuestionDAO.get(items[1].Values.pollQuestionID)>

	<!--- Check that we have the question data --->
	<cfif ArrayLen(qData)>
	<cfoutput>
		<!--- Jquery code to store the vote on submit --->
		<script type="text/javascript">
			jQuery(document).ready(function(){
			
				// Submit the Poll On Click Action
				jQuery("input##submitPoll").click( function(){
					// loop through all of the fields and pass the questionID and the value
					jQuery(".question").each(function(){
						// Get the selected value
						var selectedVal = jQuery(this).getValue();
						if (selectedVal.length) {
							var id = jQuery(this).attr("name");
							// Put up loading
							loadSaving();
							// Submit the poll form 
							submitPoll(selectedVal, id);
						}
					});
				});
				
			});
			
			// handle submitting the votes
			function submitPoll(selVal, id)
			{
				// send ajax call to post the vote
				jQuery.post("#application.ADF.ajaxProxy#",
				{
					bean: "pollVoteController",
					method: "processVote",
					questionID: id,
					vote: selVal,
					userid: "#request.user.userid#"
				},
				function(msg){
					//alert("Vote Logged");
					loadStats(id);
				});
			}
			
			// handle saving the function (adds effects)
			function loadSaving()
			{
				jQuery("##submitPoll").hide();
				jQuery("##viewResults").hide();
				
				// Block the UI
				jQuery("##poll-question").block({
					message: "<h3>Processing...</h3>",
					css: { border: "1px solid ##c0c0c0" }
				});
			}
			
			// after each post to vote - load that questions results
			function loadStats(id)
			{
				jQuery.get("#application.ADF.ajaxProxy#",
				{
					bean: "pollVoteController",
					method: "voteStatsRender",
					questionID: id
				},
				function(msg){
					jQuery("##poll-votes_" + id).html(msg);
					
					// UnBlock the UI
					jQuery("##poll-question").unblock(); 
				});
			}
			
			// if they click the 'View Results' link
			function loadResults(idList)
			{
				//var qIDArray = jQuery.ListToArray(idList);
				
				var qIDArray = idList.split(",");
				var i = 0;
				loadSaving();
				for (i; i < qIDArray.length; i++) {
					loadStats(qIDArray[i]);
				}
			}
		</script>
		
		<h3>Poll</h3>
				
		<div id="poll-question">
			<!--- // keep track of the question ids for results --->
			<cfset qIDList = listAppend(qIDList, qData[qItem].values.ID)>
			<h4>#qData[qItem].values.question#</h4>
			
			<div id="poll-votes_#qData[qItem].values.ID#">
				<!--- // If needed, covert comma-delimited (",") list to pipe-delimited list ("|") --->
				<cfset voteOptionList = qData[qItem].values.voteOptions>
				<cfif ListLen(voteOptionList,",") GT 0>		
					<cfset voteOptionList = ListChangeDelims(voteOptionList,"|",",")>	 
				</cfif>
				
				<!--- // determine the question type --->
				<cfswitch expression="#qData[qItem].values.type#">
					<!--- // Selection List --->
					<cfcase value="Selection List">
						<p>
							<select name="#qData[qItem].values.ID#" id="#qData[qItem].values.ID#" class="question">
								<option value="">- SELECT -</option>
								<cfloop list="#voteOptionList#" index="vote" delimiters ="|">
									<option value="#vote#">#vote#</option>
								</cfloop>
							</select>
						</p>
					</cfcase>
					<!--- // Radio Buttons --->
					<cfcase value="Radio Buttons">
						<!--- Loop over the options --->
						<cfset optCnt = 1>
						<cfloop list="#voteOptionList#" index="vote" delimiters="|">
							<p><input type="radio" name="#qData[qItem].values.ID#" id="#qData[qItem].values.ID#_#optCnt#" value="#Trim(vote)#" class="question">#Trim(vote)#</p>
							<cfset optCnt = optCnt + 1>
						</cfloop>
					</cfcase>
				</cfswitch>
			</div>
			
			<p>&nbsp;</p>
			<p><input type="button" id="submitPoll" name="submitPoll" value="Submit Vote"></p>
			<p><a id="viewResults" href="javascript:;" onclick="loadResults('#qIDList#');">View Results</a></p>
		</div>
		
	</cfoutput>
	</cfif>
</cfif>